#
# spec file for package gogglesmm
#
# Copyright (c) 2020 Packman Team <packman@links2linux.de>
# Copyright (c) 2010 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2008-2010 oc2pus <oc2pus@arcor.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


%define _lto_cflags %{nil}
Name:           gogglesmm
Version:        1.2.1
Release:        5.2
Summary:        Music Collection Manager and Player
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://gogglesmm.github.io/
Source:         https://github.com/gogglesmm/gogglesmm/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         gogglesmm.patch
BuildRequires:  cmake
BuildRequires:  cups-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(faad2)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gnutls) >= 3.4.0
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libopenjpeg)
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  pkgconfig(libpulse) >= 0.9.21
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(ogg) >= 1.0
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(sqlite3) > 3.6.19
BuildRequires:  pkgconfig(taglib) >= 1.9.0
BuildRequires:  pkgconfig(vorbis) >= 1.2

%description
Goggles Music Manager is a music collection manager and player that
automatically categorizes your music files based on genre, artist,
album, and song. It supports gapless playback and features easy tag
editing.

Features
* Last-FM audio scrobbler support.
* Fast and light weight. Quick startup, no splash screen needed!
* Supports Ogg Vorbis , FLAC, MP3 , MP4 , ASF and Musepack music files.
* Support for AlbumArt embedded in tag or as separate file on disk.
* Tag editing and file renaming capability (batch). One or more
  tracks may be edited at the same time.
* Smart sorting with user configurable leading word filter to
  prevent sorting on common words like the, a or an.
* Support for play lists. Play lists may be played in a certain
  configurable order, or browsed through like the main music library.
* Export music library and play lists to XSPF,PLS,Extended M3U,M3U
  and CSV.
* Clipboard & DND (drag-and-drop) support to arrange playlists and
  dragging to and from gnome / kde applications.
* Uses xine multimedia library for gapless playback.
* Written using FOX, one of the fastest GUI toolkits available.
* Customizable icons. Either use buildin icons or use an existing
  gnome/kde icon theme.
* Configurable user interface from minimalistic to detailed view.
  Full screen mode available with FOX-1.7.11.
* Clean and fast database backend using SQLite 3.

%lang_package

%prep
%autosetup -p1

%build
%cmake \
	-DBUILD_SHARED_LIBS=OFF \
	-DWITH_OPENSSL=OFF \
	%{nil}
%cmake_build

%install
%cmake_install
%find_lang %{name}

%files
%license COPYING
%doc ChangeLog README
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}
%{_datadir}/icons/hicolor
%{_datadir}/metainfo
%{_libdir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Thu Jun  4 2020 aloisio@gmx.com
- Update to version 1.2.1
  * Too many changes to list, see ChangeLog
- Switch build to cmake
- Drop gogglesmm-verbose_makefile.patch
- Spec cleanup
* Sun Dec 16 2012 pascal.bleser@opensuse.org
- update to 0.12.7:
  * support WAV files
  * ninor optimizatons
  * add disc number support in filename parser
  * support NetworkManager 0.9 notifications
  * fixes to audioscrobbler
* Tue May 29 2012 Manfred.Tremmel@iiv.de
- update to 0.12.6:
  * Fix xine 1.2 detection in configure.
* Thu Dec  8 2011 pascal.bleser@opensuse.org
- update to 0.12.5:
  * fix memory leak
  * fix libre.fm support
  * new authentication method for last.fm
  * improved compatibility/detection for m3u/pls urls when playing Internet Radio
  * removed libcurl dependency
* Sat Oct 15 2011 pascal.bleser@opensuse.org
- update to 0.12.4:
  * added Portuguese Translation by Sérgio Marques
  * improved notification daemon compatibility
  * support for latest FOX 1.7.29
  * added genre and location to mpris information
* Sat Aug 20 2011 pascal.bleser@opensuse.org
- update to 0.12.3:
  * do not pass unsupported GL_LINEAR_MIPMAP_LINEAR to GL_TEXTURE_MAG_FILTER
  * enable support for non-power-of-two textures now that Mesa 7.11-rc4 fixes the issue
  * fix incorrect usage of FXAutoPtr
  * fix parallel build
* Thu Jun  9 2011 pascal.bleser@opensuse.org
- update to 0.12.2:
  * Gnome 3 compatibility updates
  * fix infinite last.fm warnings when the system time is out of sync with the
    last.fm server time
  * merge title that were split into multiple entries in vorbiscomments
- changes from 0.12.1:
  * fix crash when right-clicking tray icon (issue 230)
  * timer fix in audioscrobbler for fox-1.7
* Tue Mar  1 2011 pascal.bleser@opensuse.org
- update to 0.12.0:
  * updated Look and Feel
  * updated Czech Translation
  * allow relative paths when exporting playlists
  * support for taglib 1.7
  * remove support for old miniplayer
  * fix audioscrobbler on FOX 1.7
- changes from 0.11.6:
  * updated Spanish Translation
  * improved opengl compatibility in cover display
- changes from 0.11.5:
  * fix ignored icon theme (issue 222)
  * initial svg icon support through use of rsvg-convert (part of librsvg)
    utility
* Wed Nov  3 2010 pascal.bleser@opensuse.org
- update to 0.11.4:
  * icon theme specification support was improved
  * the disabled mp4 support was fixed
  * improvements were made to the miniplayer
  * a crash during import was fixed
  * libgcrypt is properly initialized to avoid warnings
- changes from 0.11.2:
  * support for .oga files was added
  * scrobbling to last.fm or libre.fm is allowed
  * some threading issues in the audio scrobbler were fixed
* Mon Aug 30 2010 pascal.bleser@opensuse.org
- update to 0.11.1:
  * the Hungarian translation was updated
- changes from 0.11.0:
  * the built-in icon set has been removed, and gogglesmm will now load its icons from the standard icon themes in /usr/share/icons
  * a new partial MPRIS D-bus interface has been added
* Fri Aug 20 2010 toni@links2linux.de
- update to 0.10.27
- This release will use the proper URI during dnd (file://<path> instead
  of file:<path>).
- A man page has been added.
* Thu Jul 15 2010 pascal.bleser@opensuse.org
- update to 0.10.26
* Wed May 12 2010 toni@links2linux.de
- update to 0.10.22
- A Czech translation was added.
* Mon May  3 2010 toni@links2linux.de
- update to 0.10.20
- Tray icon background color may now be customized to improve the look of the tray icon.
- The ability to load album art from a tag in the album browser as well.
- The main library listing genres from the Radio Streams has been fixed.
- Empty genre tags in the database (issue 162) have been fixed.
- This release will not try to install mo files it doesn't have when the LINGUAS
  environment variable is set (issue 165).
- libfetch support has been removed and replaced by libcurl.
* Thu Mar  4 2010 toni@links2linux.de
- update to 0.10.19
- Media keys are supported through the Gnome Settings Daemon.
- The import dialog is not shown when radio streams are in the database.
- The EWMH icon hint is used to specify an application icon, which should
  result in a nicer looking icon in the taskbar.
- Various dbus event handling problems were fixed to prevent crashes.
* Tue Feb  9 2010 toni@links2linux.de
- update to 0.10.18
- The program is now more flexible about the HTTP return code in the last.fm
  scrobbler.
- A crash when pressing delete on "All Arists/Genres/Albums" was fixed.
- Minor cleanups were made.
* Mon Jan 25 2010 toni@links2linux.de
- update to 0.10.17
- This release adds a Russian translation.
* Sat Jan  9 2010 toni@links2linux.de
- update to 0.10.16
- A Hungarian translation was added.
- A compilation issue with pre 1.6 taglib versions was fixed.
- update to 0.10.15
- This release supports BMP and GIF embedded album art.
- It has additional signal handler(s) to correctly save state on exit.
- It fixes focus getting stuck on the Edit Track dialog.
  The year field in the edit track dialog should be empty if multiple
  tracks with different years are selected.
- A memory leak in the embedded album art loader has been fixed.
* Mon Dec 28 2009 toni@links2linux.de
- update to 0.10.14
- This release adds support for *.m4b files and fixes some minor issues.
* Fri Dec  4 2009 toni@links2linux.de
- update to 0.10.13
- The disc number is now taken into account when sorting.
* Wed Nov 25 2009 toni@links2linux.de
- update to 0.10.12
- The German translation was updated.
* Tue Nov 17 2009 toni@links2linux.de
- update to 0.10.11
- This release fixes a crash when using an XIM-enabled version FOX. It fixes
  timeout type mixup with FOX-1.6 vs FOX-1.7.
* Fri Nov  6 2009 toni@links2linux.de
- update to 0.10.10
- A crash which occurred when removing a file from the library via a playlist was
  fixed.
* Wed Oct 28 2009 toni@links2linux.de
- update to 0.10.9
- This release fixes several critical bugs that could cause GMM to crash.
  libdownload support has been removed. In order to play m3u and pls Internet
  radio streams, please install libfetch instead.
* Wed Oct 21 2009 toni@links2linux.de
- update to 0.10.7
- French translations were added. taglib-extras is supported as a replacement for
  the builtin MP4/ASF support. Other scrobbler compatiable servers are allowed to
  be used like libre.fm. A critical bug when sending album art to a notification
  daemon was fixed. The time/duration display was fixed to account for tracks
  longer than an hour. Support for FOX 1.7.20 was added.
* Fri Jun 19 2009 toni@links2linux.de
- update to 0.10.3
  Translation fixes and updates were made. Compilation with taglib-1.4
  was fixed. The user is warned when an incompatible (future) version
  of the database is encountered.
* Fri Jun  5 2009 toni@links2linux.de
- update to 0.10.2
  A Spanish translation was added. A bug that prevented translations
  from working with FOX-1.7 was fixed
* Thu Jun  4 2009 toni@links2linux.de
- update to 0.10.1
  A German translation was added. Tray icon issues were fixed. Special
  characters in the audio scrobbler now playing submitter are properly
  encoded. Sorting of album list by year in playlists was fixed. Grabbing
  of all keys in certain cases was fixed
* Sun May 31 2009 toni@links2linux.de
- update to 0.10.0
  Major new features including per-track-artist support, replay gain,
  equalizer, and overall enhancements to the user interface.
* Mon Nov 24 2008 toni@links2linux.de
- initial build 0.9.16
